/* 
 * File:   pressure.h
 * Author: matthewmagaldi
 *
 * Created on November 17, 2015, 9:34 AM
 */

#ifndef PRESSURE_H
#define	PRESSURE_H

/*=========================================================================
    REGISTERS
    -----------------------------------------------------------------------*/
 
#define    BMP183_REGISTER_CAL_AC1            0xAA  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_AC2            0xAC  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_AC3            0xAE  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_AC4            0xB0  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_AC5            0xB2  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_AC6            0xB4  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_B1             0xB6  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_B2             0xB8  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_MB             0xBA  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_MC             0xBC  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CAL_MD             0xBE  // R   Calibration data (16 bits)
#define    BMP183_REGISTER_CHIPID             0xD0
#define    BMP183_REGISTER_VERSION            0xD1
#define    BMP183_REGISTER_SOFTRESET          0xE0
#define    BMP183_REGISTER_CONTROL            0xF4
#define    BMP183_REGISTER_TEMPDATA           0xF6
#define    BMP183_REGISTER_PRESSUREDATA       0xF6
#define    BMP183_REGISTER_READTEMPCMD        0x2E
#define    BMP183_REGISTER_READPRESSURECMD    0x34

/*=========================================================================
    MODE SETTINGS
    -----------------------------------------------------------------------*/
 
#define    BMP183_MODE_ULTRALOWPOWER           0
#define    BMP183_MODE_STANDARD                1
#define    BMP183_MODE_HIGHRES                 2
#define    BMP183_MODE_ULTRAHIGHRES            3

/*=========================================================================
    PIN CONNECTIONS & VARIABLES
    -----------------------------------------------------------------------*/
#define SEA_LEVEL_PRESSURE 101325
static short AC1;
static short AC2;
static short AC3;
static unsigned short AC4;
static unsigned short AC5;
static unsigned short AC6;
static short B1;
static short B2;
static short MB;
static short MC;
static short MD;

static char oversampling;

//CHIP SELECT - RPB7
#define PR_CS         LATBbits.LATB7    //physical pin 16
#define PR_CS_dir     TRISBbits.TRISB7

#define PBCLK 40000000              // peripheral bus clock
#define SPI2_freq    2000000        // max is 10Mhz
#define dTimeMs PBCLK/1000          //check this to be right

/*=========================================================================
    USER FUNCTIONS
    -----------------------------------------------------------------------*/
void pressure_begin(unsigned char);
void spiwrite(unsigned char, unsigned char);
unsigned char spiread8(unsigned char);
unsigned int spiread16(unsigned char);
void delayMs(unsigned long );

void read_calibration_data(void);
UINT16 read_raw_temperature(void);
UINT32 read_raw_pressure(void);

float get_temperature(void);
INT32 get_pressure(void);
float get_altitude(void); // std atmosphere
#endif	/* PRESSURE_H */